==> go.php?file=PhoenixStyle1.55902.zip: PhoenixStyleMod_DragonSoul/Ultraxion.lua <==
﻿psbossfile65=1
function pscmrboss651(guid2,name2,spellname)
if pswasonboss65==nil then
	pswasonboss65=1
end
psunitisplayer(guid2,name2)
if psunitplayertrue then
	pscheckwipe1()
	if pswipetrue and pswasonboss65~=2 then
		psiccwipereport_3("wipe", "try")
	end
		addtotwotables(name2)
		vezaxsort1()
		psunitisplayer(guid2,name2)
		if psunitplayertrue then
		if psraidoptionson[6][1][1]==1 and pswasonboss65==1 then
			if UnitSex(name2) and UnitSex(name2)==3 then
				pszapuskanonsa(psraidchats3[psraidoptionschat[6][1][1]], "{rt8} "..name2.." "..psmainmgotinf.." |s4id99837|id!")
			else
				pszapuskanonsa(psraidchats3[psraidoptionschat[6][1][1]], "{rt8} "..name2.." "..psmainmgotinm.." |s4id99837|id!")
			end
		end
		end

		pscaststartinfo(0,spellname..": "..psaddcolortxt(1,name2)..name2..psaddcolortxt(2,name2), -1, "id1", 1, spellname.." - "..psinfo,psbossnames[6][5],2)

end
end

function pscmrboss652(guid2,name2,spellname)
if pswasonboss65==nil then
	pswasonboss65=1
end
psunitisplayer(guid2,name2)
if psunitplayertrue then
	pscheckwipe1()
	if pswipetrue and pswasonboss65~=2 then
		psiccwipereport_3("wipe", "try")
	end
		addtotwotables2(name2)
		vezaxsort2()

		pscaststartinfo(0,spellname..": "..psaddcolortxt(1,name2)..name2..psaddcolortxt(2,name2), -1, "id1", 2, spellname.." - "..psinfo,psbossnames[6][5],2)
end
end




function pscmrbossREPORT651(wipe,try,reset,checkforwipe)
if reset==nil then
if checkforwipe==nil or (checkforwipe and pswasonboss65 and pswasonboss65==1) then

	if pswasonboss65==1 then
		pssetcrossbeforereport1=GetTime()
		if psraidoptionson[6][5][2]==1 then
			strochkavezcrash=psmainmgot.." |s4id99837|id ("..psmainmtotal.."): "
			reportafterboitwotab(psraidchats3[psraidoptionschat[6][5][2]], true, vezaxname, vezaxcrash, 1)
		end



	end
	if pswasonboss65==1 or (pswasonboss65==2 and try==nil) then

		psiccsavinginf(psbossnames[6][5], try, pswasonboss65)

		strochkavezcrash=psmainmgot.." |s4id99837|id: "
		reportafterboitwotab("raid", true, vezaxname, vezaxcrash, nil, nil,0,1)


		psiccrefsvin()

	end




	if wipe then
		pswasonboss65=2
		pscheckbossincombatmcr_3=GetTime()+1
	end
end
end
end


function  pscmrbossRESET651(wipe,try,reset,checkforwipe)
if reset or wipe==nil then
pswasonboss65=nil
table.wipe(vezaxname)
table.wipe(vezaxcrash)
table.wipe(vezaxname2)
table.wipe(vezaxcrash2)
end
end


function pscombatlogboss65(arg1, arg2, hideCaster, guid1, name1, flag1, new1, guid2, name2, flag2, new2, spellid, spellname, arg11,arg12,arg13,arg14,arg15)


--сейанонсеры
--if arg2=="SPELL_SUMMON" and (spellid==99836) then
--if ps_saoptions[6][1][1]==1 then
--ps_sa_checktargets(GetTime()+0.17,guid1,0.2,spellname.." "..psmain_sa_phrase1,3,0)
--end
--end

if arg2=="SPELL_AURA_APPLIED" and spellid==998370 then
pscmrboss651(guid2,name2,spellname)
end

if arg2=="SPELL_AURA_APPLIED" and (spellid==998380 or spellid==1012080 or spellid==1012090 or spellid==1012100) then
pscmrboss652(guid2,name2,spellname)
end




end

==> go.php?file=PhoenixStyle1.55904.zip: PhoenixStyleMod_DragonSoul/Ultraxion.lua <==
﻿psbossfile65=1
function pscmrboss651(guid2,name2,spellname)
if pswasonboss65==nil then
	pswasonboss65=1
end
psunitisplayer(guid2,name2)
if psunitplayertrue then
	pscheckwipe1()
	if pswipetrue and pswasonboss65~=2 then
		psiccwipereport_3("wipe", "try")
	end
		addtotwotables(name2)
		vezaxsort1()
		psunitisplayer(guid2,name2)
		if psunitplayertrue then
		if psraidoptionson[6][1][1]==1 and pswasonboss65==1 then
			if UnitSex(name2) and UnitSex(name2)==3 then
				pszapuskanonsa(psraidchats3[psraidoptionschat[6][1][1]], "{rt8} "..name2.." "..psmainmgotinf.." |s4id99837|id!")
			else
				pszapuskanonsa(psraidchats3[psraidoptionschat[6][1][1]], "{rt8} "..name2.." "..psmainmgotinm.." |s4id99837|id!")
			end
		end
		end

		pscaststartinfo(0,spellname..": "..psaddcolortxt(1,name2)..name2..psaddcolortxt(2,name2), -1, "id1", 1, spellname.." - "..psinfo,psbossnames[6][5],2)

end
end

function pscmrboss652(guid2,name2,spellname)
if pswasonboss65==nil then
	pswasonboss65=1
end
psunitisplayer(guid2,name2)
if psunitplayertrue then
	pscheckwipe1()
	if pswipetrue and pswasonboss65~=2 then
		psiccwipereport_3("wipe", "try")
	end
		addtotwotables2(name2)
		vezaxsort2()

		pscaststartinfo(0,spellname..": "..psaddcolortxt(1,name2)..name2..psaddcolortxt(2,name2), -1, "id1", 2, spellname.." - "..psinfo,psbossnames[6][5],2)
end
end




function pscmrbossREPORT651(wipe,try,reset,checkforwipe)
if reset==nil then
if checkforwipe==nil or (checkforwipe and pswasonboss65 and pswasonboss65==1) then

	if pswasonboss65==1 then
		pssetcrossbeforereport1=GetTime()
		--if psraidoptionson[6][5][2]==1 then
		--	strochkavezcrash=psmainmgot.." |s4id99837|id ("..psmainmtotal.."): "
		--	reportafterboitwotab(psraidchats3[psraidoptionschat[6][5][2]], true, vezaxname, vezaxcrash, 1)
		--end



	end
	if pswasonboss65==1 or (pswasonboss65==2 and try==nil) then

		psiccsavinginf(psbossnames[6][5], try, pswasonboss65)

		strochkavezcrash=psmainmgot.." |s4id99837|id: "
		reportafterboitwotab("raid", true, vezaxname, vezaxcrash, nil, nil,0,1)


		psiccrefsvin()

	end




	if wipe then
		pswasonboss65=2
		pscheckbossincombatmcr_3=GetTime()+1
	end
end
end
end


function  pscmrbossRESET651(wipe,try,reset,checkforwipe)
if reset or wipe==nil then
pswasonboss65=nil
table.wipe(vezaxname)
table.wipe(vezaxcrash)
table.wipe(vezaxname2)
table.wipe(vezaxcrash2)
end
end


function pscombatlogboss65(arg1, arg2, hideCaster, guid1, name1, flag1, new1, guid2, name2, flag2, new2, spellid, spellname, arg11,arg12,arg13,arg14,arg15)


--сейанонсеры
--if arg2=="SPELL_SUMMON" and (spellid==99836) then
--if ps_saoptions[6][1][1]==1 then
--ps_sa_checktargets(GetTime()+0.17,guid1,0.2,spellname.." "..psmain_sa_phrase1,3,0)
--end
--end

if arg2=="SPELL_AURA_APPLIED" and spellid==998370 then
pscmrboss651(guid2,name2,spellname)
end

if arg2=="SPELL_AURA_APPLIED" and (spellid==998380 or spellid==1012080 or spellid==1012090 or spellid==1012100) then
pscmrboss652(guid2,name2,spellname)
end




end
